-- Robin animation

local gr, down = love.graphics, love.keyboard.isDown
local pi, floor, ceil = math.pi, math.floor, math.ceil

function love.load()
	gr.setCaption( 'Spritesheet Analysis' )
	gr.setBackgroundColor( 0, 55, 155, 255 )
	w, h = 900, 600
	gr.setMode( w, h, {} )
	sheetname = 'cheetahclassic.png'
	image		= gr.newImage( sheetname )
	Iw, Ih		= image:getWidth(), image:getHeight()
	wd			= 90
	ht			= 100
	x			= 90
	y			= 5
	Wx, Wy, Ws	= 500, 50, 0.33
	gt, nm		= 0, 1
	Quad={{ 90,   5, 90,100},{181,   9, 90,100},{277,  11, 90,100},{370,  10, 90,100},{450,  10, 90,100},
		  {  0, 111, 90,100},{101, 111,104,100},{203, 114, 99,117},{286, 120, 90,117},{384, 111, 90,117},{465,111,96,117},
		  { 17, 211,104,117},{133, 241,104,117},{240, 248,129,117},{385, 218,129, 91},
		  { 17, 321, 90, 91},{130, 338,146, 84},{283, 365,121, 94},{424, 332,105, 96},
		  { 15, 434,105, 90},{133, 429, 90,115},{287, 465, 90,115},{372, 480,122, 90},
		  { 11, 531,122,100},{133, 541,120,100},{368, 581,120,100},{ 10, 645,122, 90},{127, 647, 94,109},
		  {  6, 746,114,100},{132, 744,114, 87},{257, 711, 82, 94},{337, 707, 90,100},{442, 710,137,109},
		  { 13, 855,100,109},{118, 855,100,109},{220, 837,100,109},{342, 830,131,109},{462, 830,131,109},
		  { 15, 967,110, 96},{120, 969,135, 96},{388, 960,135, 96},
		  { 29,1065, 95,100},{102,1073,110,100},{234,1073,110,100},{365,1061,106,100},{461,1070,125,100},
		  { 13,1171,125,100},{151,1194,125, 85},{281,1192,116, 85},{396,1192,145, 85},
		  {  5,1286,134, 85},{135,1280,115,106},{242,1280,115,106},{357,1280,103,111},{472,1280,103,111},
		  {  0,1378,103,120},{136,1383,103,120},{348,1387,103,120},{444,1384,103,120},
		  { 13,1535,100,120},{120,1531,100,120},{202,1533,100,120},{302,1528,100,120},{418,1568,114, 81},
		  {  0,1695, 96 ,90},{126,1671,100,100},{231,1666,100,118},{338,1645,100,118},{448,1634,105,118}}
	Quads = {}
	for i = 1, #Quad do
		Quads[i] = gr.newQuad( Quad[i][1], Quad[i][2], Quad[i][3], Quad[i][4], Iw, Ih )
		end
	run = true
	end

function love.update( dt )
	if down( 'd' )		then wd = wd + 1 end
	if down( 'a'  )		then wd = wd - 1 end
	if down( 'w' )		then ht = ht + 1 end
	if down( 's' )		then ht = ht - 1 end
	if down( 'up' )		then y  =  y > 1 and y - 1 or 0 end
	if down( 'down' )	then y  =  y < Ih and y + 1 or Ih end
	if down( 'left' )	then x  =  x > 1 and x - 1 or 0 end
	if down( 'right' )	then x  =  x < Iw - 1 and x + 1 or Iw end
	quad = gr.newQuad( x, y, wd, ht, Iw, Ih )
	if run then gt = gt + 2 * dt end
	if gt > 0.5 then gt = 0 nm = nm < #Quads and nm + 1 or 1 end
	text =
[[Key Inputs:
Course: Up, Down, Left, Right > Arrow keys
        Window Width & Height > WSAD
Find:   UP, Down, Left, Right > IMJK
        Window Width & Height > TFGV
Toggle Running: > R
]]
	end

function love.draw()
	gr.setColor( 255, 255, 255, 255 )
	gr.drawq( image, quad, Wx, Wy, 0, 2, 2 )					-- working image
	gr.rectangle( 'line', Wx, Wy, 2 * wd, 2 * ht )
	gr.print('X, Y, Width, Height: '..x..', '..y..', '..wd..', '..ht, Wx, 30 )

	gr.line( Wx + wd, Wy, Wx + wd, Wy + 2 * ht )				-- cross hairs
	gr.line( Wx, Wy + ht, Wx + 2 * wd, Wy + ht )

	gr.drawq( image, quad, 650, 350 )							-- actual image
	gr.rectangle( 'line', 650, 350, wd, ht )
	gr.print('Actual size',650,350+wd+20)

	gr.draw( image, 0, 0, 0, Ws, Ws )							-- draw spritesheet
	gr.rectangle('line', 1, 1, Ws * Iw, Ws * Ih )				-- outline spritesheet

	gr.rectangle( 'line', Ws * x, Ws * y, Ws * wd, Ws * ht )	-- show position on sheet

	gr.setColor( 255, 255, 255 )								-- draw animation
	gr.drawq( image, Quads[nm], 401, 351 )
	gr.setColor( 0, 255, 255 )									-- outline animation
	gr.rectangle( 'line', 400, 350, 140, 120 )

	gr.setColor( 255, 0, 0 )									-- show source of animation
	gr.rectangle('line',Ws*Quad[nm][1],Ws*Quad[nm][2],Ws*Quad[nm][3],Ws*Quad[nm][4])

	gr.setColor(255,255,255)									-- show quad settings
	gr.print(Quad[nm][1]..', '..Quad[nm][2]..', '..Quad[nm][3]..', '..Quad[nm][4],420,490)
	gr.print(text,500,510)
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.quit() 	end
	if key == 'f'		then wd = wd - 1  end
	if key == 'g'		then wd = wd + 1  end
	if key == 't'		then ht = ht + 1  end
	if key == 'v'		then ht = ht - 1  end
	if key == 'm' 		then y  = y  > 1  and y - 1 or 0  end
	if key == 'i'		then y  = y  < Ih and y + 1 or Ih end
	if key == 'j'		then x  = x  > 1  and x - 1 or 0  end
	if key == 'k'		then x  = x  < Iw-1  and x + 1 or Iw  end
	if key == 'n'		then nm = nm < #Quad and nm + 1 or 1  end
	if key == 'h'		then nm = nm > 1  and nm - 1 or #Quad end
	if key == 'r'		then run = not run end
	if key == 'p'		then process = not process end
	end
